Changes for v0.9.5 (2017-08-16)
===============================

Stream printing to console & print bytes Jmackey popup auth Publish
python bindings to readthedocs

Changes for v0.9.3 (2017-08-04)
===============================

Removing popup capability to release functioning package.

Popups weren't working because client\_secrets.json is required and
wasn't being published with the package.

Changes for v0.9.2 (2017-08-04)
===============================

Add client\_secrets.json to MANIFEST directory.

Changes for v0.9.1 (2017-08-04)
===============================

Fix auto-path set Set config to ~/.config/hca/oauth2.json Reconfigure
auth to include sign-in pop-up if in a teletype

Changes for v0.9.0 (2017-08-02)
===============================

Full python binding support for all endpoints: \* bundles \* files \*
search \* subscriptions

CLI integration on top of these python bindings

Changes for v0.7.0 (2017-08-02)
===============================

Full python binding support for all endpoints: \* bundles \* files \*
search \* subscriptions

CLI integration on top of these python bindings

Changes for v0.7.3 (2017-08-01)
===============================

Add kwarg to redirect to different url.

Changes for v0.7.2 (2017-08-01)
===============================

Remove merge conflict lines.

Changes for v0.7.1 (2017-08-01)
===============================

Fix google auth request import

Changes for v0.7.0 (2017-08-01)
===============================

remove sign so I can release v0.7.0 remove tuple comprehension (python3
doesn't like that) Remove cli tests. Python bindings w/ auth and some
testing Autogenerated functions fully working. making abstractions a
package. Upload/Download refactor: Moved upload/download commands to
hca/api/abstractions dir. Release file resources after completed.
Cherry-picked upload-from-s3 changes Testing head\_files. Don't
regenerate python bindings. Templatize relative imports from
autogenerated. Remove unnecessary import Relative imports from
autogenerated Include all jinja files and update tests. Populate test
bundle with real data avoid namespace collision New python bindings
after positional args sorting. Sorted positional args to maintain
consistent order. Add jsonschema to install requirements. Add Jinja2 to
setup.py requirements. Generate fully functional python bindings with
docs attached. Remove .travis.yml changes b/c they landed on a pr that's
already been merged. Added region env variable to travis. Create classes
that add functions/parsers for each endpoint. (#20) Add AddedCommand
superclass for all api endpoints. (#19)

Changes for v0.7.0 (2017-08-01)
===============================

remove tuple comprehension (python3 doesn't like that) Remove cli tests.
Python bindings w/ auth and some testing Autogenerated functions fully
working. making abstractions a package. Upload/Download refactor: Moved
upload/download commands to hca/api/abstractions dir. Release file
resources after completed. Cherry-picked upload-from-s3 changes Testing
head\_files. Don't regenerate python bindings. Templatize relative
imports from autogenerated. Remove unnecessary import Relative imports
from autogenerated Include all jinja files and update tests. Populate
test bundle with real data avoid namespace collision New python bindings
after positional args sorting. Sorted positional args to maintain
consistent order. Add jsonschema to install requirements. Add Jinja2 to
setup.py requirements. Generate fully functional python bindings with
docs attached. Remove .travis.yml changes b/c they landed on a pr that's
already been merged. Added region env variable to travis. Create classes
that add functions/parsers for each endpoint. (#20) Add AddedCommand
superclass for all api endpoints. (#19)

Changes for v0.6.0 (2017-07-12)
===============================

Changes for v0.5.0 (2017-07-12)
===============================

Changes for v0.4.0 (2017-07-12)
===============================

Changes for v0.3.0 (2017-07-12)
===============================

v0.3.0 Support uploading bundle from staged s3 bucket to DSS. Fix upload
from local bug.

Changes for v0.3.0 (2017-07-12)
===============================

Support uploading bundle from staged s3 bucket to DSS. Fix bug in hca
upload.

Changes for v0.2.0 (2017-07-12)
===============================

-  Initial release.

Changes for v0.1.0 (2017-06-27)
===============================

-  Demo version pre-release

Command line interface that interacts with the Human Cell Atlas data
store REST API.

Current functionality: Retrieve or register a data file. Retrieve or
register a data bundle (collection of data files). Upload full directory
to cloud, register given files, and collect them into a bundle. Download
a bundle or file from HCA data store to local.

Changes for v1.0.0 (2017-06-26)
===============================

Changes for v0.0.8 (2017-06-06)
===============================

Test release
------------

Changes for v0.0.7 (2017-06-06)
===============================

Test release
------------

Changes for v0.0.6 (2017-06-06)
===============================

Test release
------------

Changes for v0.0.5 (2017-06-06)
===============================

Test release
------------

Changes for v0.0.4 (2017-06-06)
===============================

Test release
------------

Changes for v0.0.3 (2017-06-06)
===============================

Test Release
------------

Changes for v0.0.2 (2017-06-06)
===============================

Test release
------------

Changes for v0.0.1 (2017-06-06)
===============================

Test Release
------------

Changes for v0.0.1 (2017-06-06)
===============================

Test Release
------------

Changes for v0.0.1 (2017-06-06)
===============================

Test release
~~~~~~~~~~~~

